@@ -1,7 +1,8 @@
-from quaterion.loss.arcface_loss import ArcfaceLoss
+from quaterion.loss.arcface_loss import ArcFaceLoss
 from quaterion.loss.contrastive_loss import ContrastiveLoss
 from quaterion.loss.group_loss import GroupLoss
 from quaterion.loss.metrics import SiameseDistanceMetric
 from quaterion.loss.pairwise_loss import PairwiseLoss
 from quaterion.loss.similarity_loss import SimilarityLoss
 from quaterion.loss.softmax_loss import SoftmaxLoss
+from quaterion.loss.triplet_loss import TripletLoss
